pub type Result<T> = Result<T, ProfileError>;Expand description
The canonical Result type alias used throughout the crate.
Aliased Type
pub enum Result<T> {
Ok(T),
Err(ProfileError),
}pub type Result<T> = Result<T, ProfileError>;The canonical Result type alias used throughout the crate.
pub enum Result<T> {
Ok(T),
Err(ProfileError),
}